package cz.zweistein.df.soundsense.config;

import java.util.List;
import java.util.Random;

public class Sound {
	
	private List<SoundFile> soundFiles;
	private int soundFilesWeightsSum;
	
	private String logPattern;
	
	// loop repeats indefinitely, only music can loop
	private MusicLoop loop;
	// there can be only one music-type sound played
	private boolean music;
	// concurency is cap on how many sounds can be played concurenctly to this one.
	// if more sounds are playing than this number and this sound is triggered, it would be ignored.
	private Integer concurency; 
	// is set, engine echoes log line 
	private boolean speech;
	
	public Sound(List<SoundFile> soundFiles, String logPattern, MusicLoop loop, boolean music, Integer concurency, boolean speech) {
		this.soundFiles = soundFiles;
		this.logPattern = logPattern;
		this.loop = loop;
		this.music = music;
		this.concurency = concurency;
		this.speech = speech;
		
		this.soundFilesWeightsSum = 0;
		for (SoundFile soundFile: this.soundFiles) {
			this.soundFilesWeightsSum += soundFile.getWeight();
		}
		
	}

	public boolean getSpeech() {
		return this.speech;
	}

	public Integer getConcurency() {
		return this.concurency;
	}
	
	public String getLogPattern() {
		return this.logPattern;
	}
	
	public MusicLoop getLoop() {
		return this.loop;
	}

	public boolean getMusic() {
		return this.music;
	}

	public String getSoundFile() {
		
		if (this.soundFiles.size() > 0) {
			int weightedRandom = new Random().nextInt(this.soundFilesWeightsSum);
			for (SoundFile soundFile: this.soundFiles) {
				if (soundFile.getWeight() > weightedRandom) {
					return soundFile.getFileName();
				}
				weightedRandom -= soundFile.getWeight();
			}
			
		}
	
		return null;
		
	}

}
